@@ -1,12 +1,24 @@
 # Module to reduce boilerplate code in unburden-home-dir's test suite
 use strict;
 
+# Note about why using File::Slurper and not Path::Tiny:
+#
+# * Path::Tiny could replace File::Slurper, File::Path and File::Temp.
+# * But File::Path and File::Temp are part of Perl's core,
+#   i.e. usually always already installed.
+# * For the additionally required functionality, i.e. pure slurp/spew
+#   functionality, I prefer the smaller and simpler module, i.e.
+#   File::Slurper (24kB unpacked .deb) over Path::Tiny (158kB).
+#
+# See
+# http://blogs.perl.org/users/leon_timmermans/2015/08/fileslurp-is-broken-and-wrong.html
+# for some more background on this discussion.
+
 # Boilerplate which exports into main::
 use Test::More;
 use Test::Differences;
 use Test::File '1.30';
 use File::Path qw(mkpath);
-use File::Slurp;
 use Data::Dumper;
 
 package Test::UBH;
@@ -18,12 +30,14 @@ use Test::More;
 use Test::Differences;
 use Test::File;
 use File::Path qw(mkpath rmtree);
-use File::Slurp;
+use File::Slurper qw(read_text write_text);
 use File::Temp;
 use File::Which;
 use String::Random qw(random_string);
 use Data::Dumper;
 
+no warnings 'utf8';
+
 sub ubh_temp_dir {
     return File::Temp->newdir(DIR => 't');
 }
@@ -46,6 +60,10 @@ sub BUILD {
     $ENV{HOME} = $t->HOME;
     $ENV{LANG} = 'C';
 
+    # For testing environment variable expansion inside the
+    # configuration file.
+    $ENV{PERCENT_S} = '%s';
+
     # Clean up possible remainders of aborted tests
     rmtree($t->BASE);
 
@@ -91,7 +109,7 @@ sub create_and_check_directory {
 
 sub default_config {
     my $t = shift;
-    return "TARGETDIR=".$t->TARGET."\nFILELAYOUT=".$t->PREFIX."-\%s";
+    return "TARGETDIR=".$t->TARGET."\nFILELAYOUT=".$t->PREFIX.'-${PERCENT_S}';
 }
 
 sub prepend_lsof_warning {
@@ -207,7 +225,7 @@ sub write_config_file {
     BAIL_OUT('write_config_file: $file empty') unless $file;
     BAIL_OUT('write_config_file: $contents undefined') unless defined $contents;
 
-    ok( write_file($file, $contents), $desc || "Write config file $file" );
+    ok( $t->write_file($file, $contents), $desc || "Config file $file has been written" );
 }
 
 sub shell_capture {
@@ -236,7 +254,7 @@ sub eq_or_diff_file {
     my $t = shift;
     my ($file, $desc, $wanted) = @_;
     $file = $t->BASE."/$file";
-    my $output = read_file($file);
+    my $output = read_text($file);
 
     # Filter out lsof warnings caused by systemd
     my $trailing_newline = $output =~ /\n\z/;
@@ -251,14 +269,20 @@ sub eq_or_diff_file {
 
     # Somewhere between coreutils 8.13 (until Wheezy/Quantal), and
     # 8.20 (from Jessie/Raring on) the quoting characters in verbose
-    # output of mv. changed. $wanted contains the newer style. In case
+    # output of "mv" changed. $wanted contains the newer style. In case
     # this test runs with older version of coreutils, we change the
-    # output to look like the one from the newer versions.
-    $output =~ s/\`/\'/g;
+    # output to look like the one from the newer versions.  Depending
+    # on locale settings, it might be even some UTF-8 characters
+    $output =~ s/[\`\x{2018}-\x{201f}]/\'/g;
 
     unified_diff;
     eq_or_diff_text( $output, $wanted || '', "Check $desc" );
     ok( unlink($file), "Clean cache file ($desc)" );
 }
 
+sub write_file {
+    shift;
+    eval { write_text(@_); return 1; };
+}
+
 1;
